@@ -1,7 +1,7 @@
 package JSON::Schema::AsType;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: generates Type::Tiny types out of JSON schemas
-$JSON::Schema::AsType::VERSION = '0.0.2';
+$JSON::Schema::AsType::VERSION = '0.1.0';
 use 5.10.0;
 
 use strict;
@@ -16,6 +16,7 @@ use Types::Standard qw/InstanceOf HashRef StrictNum Any Str ArrayRef Int Object
 use Type::Utils;
 use LWP::Simple;
 use Clone 'clone';
+use Class::Load qw/ load_class /;
 
 use Moose::Util qw/ apply_all_roles /;
 
@@ -77,6 +78,27 @@ has specification => (
     isa => enum 'JsonSchemaSpecification', [ qw/ draft3 draft4 / ],
 );
 
+sub specification_schema {
+    my $self = shift;
+
+    my $spec = $self->specification;
+
+    my $class  = "JSON::Schema::AsType::" . ucfirst $spec;
+
+    load_class( $class );
+
+    return eval '$'.$class . "::SpecSchema";
+}
+
+sub validate_schema {
+    my $self = shift;
+    $self->specification_schema->validate($self->schema);
+}
+
+sub validate_explain_schema {
+    my $self = shift;
+    $self->specification_schema->validate_explain($self->schema);
+}
 
 sub root_schema {
     my $self = shift;
@@ -212,7 +234,7 @@ JSON::Schema::AsType - generates Type::Tiny types out of JSON schemas
 
 =head1 VERSION
 
-version 0.0.2
+version 0.1.0
 
 =head1 SYNOPSIS
 
@@ -284,6 +306,20 @@ Returns a short explanation if C<$struct> didn't validate, nothing otherwise.
 
 Returns a log explanation if C<$struct> didn't validate, nothing otherwise.
 
+=head2 validate_schema
+
+Like C<validate>, but validates the schema itself against its specification.
+
+    print $schema->validate_schema;
+
+    # equivalent to
+
+    print $schema->specification_schema->validate($schema);
+
+=head2 validate_explain_schema
+
+Like C<validate_explain>, but validates the schema itself against its specification.
+
 =head2 schema
 
 Returns the JSON schema, as a hashref.
@@ -306,6 +342,11 @@ Returns the uri associated with the schema, if any.
 
 Returns the JSON Schema specification used by the object.
 
+=head2 specification_schema
+
+Returns the L<JSON::Schema::AsType> object representing the schema of 
+the current object's specification.
+
 =head2 root_schema
 
 Returns the top-level schema including this schema.
