@@ -1,7 +1,7 @@
 package JSON::Schema::AsType::Draft3;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Role processing draft3 JSON Schema 
-$JSON::Schema::AsType::Draft3::VERSION = '0.0.2';
+$JSON::Schema::AsType::Draft3::VERSION = '0.1.0';
 
 use strict;
 use warnings;
@@ -107,7 +107,7 @@ sub _keyword_dependencies {
     return $type;
 }
 
-JSON::Schema::AsType->new(
+our $SpecSchema = JSON::Schema::AsType->new(
     specification => 'draft3',
     uri           => 'http://json-schema.org/draft-03/schema',
     schema        => from_json <<'END_JSON' );
@@ -299,7 +299,7 @@ JSON::Schema::AsType::Draft3 - Role processing draft3 JSON Schema
 
 =head1 VERSION
 
-version 0.0.2
+version 0.1.0
 
 =head1 DESCRIPTION
 
