@@ -1,7 +1,7 @@
 package JSON::Schema::AsType::Draft4;
 our $AUTHORITY = 'cpan:YANICK';
 # ABSTRACT: Role processing draft4 JSON Schema 
-$JSON::Schema::AsType::Draft4::VERSION = '0.0.2';
+$JSON::Schema::AsType::Draft4::VERSION = '0.1.0';
 
 use strict;
 use warnings;
@@ -358,7 +358,7 @@ sub _keyword_items {
 }
 
 
-JSON::Schema::AsType->new(
+our $SpecSchema = JSON::Schema::AsType->new(
     specification => 'draft4',
     uri           => 'http://json-schema.org/draft-04/schema',
     schema        => from_json <<'END_JSON' );
@@ -526,7 +526,7 @@ JSON::Schema::AsType::Draft4 - Role processing draft4 JSON Schema
 
 =head1 VERSION
 
-version 0.0.2
+version 0.1.0
 
 =head1 DESCRIPTION
 
